==> DAAG_0.34.tar.gz: DAAG/data/hills2000.R <==
"hills2000" <-
structure(list(h = c(0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 
4, 0, 0, 1, 0, 1, 0, 1, 0, 0, 1, 3, 0, 0, 8, 0, 0, 0, 1, 0, 2, 
15, 1, 1, 0, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 
0, 2, 0, 0, 0, 1, 0, 1, 0, 0, 0, 1, 0, 1, 2, 1, 2, 0, 0, 0, 0, 
0), m = c(24, 15, 29, 23, 46, 47, 18, 27, 32, 37, 27, 16, 24, 
20, 28, 23, 44, 59, 33, 2, 23, 13, 25, 40, 43, 6, 29, 37, 18, 
44, 33, 37, 11, 22, 13, 26, 32, 11, 25, 11, 44, 34, 38, 19, 26, 
44, 46, 30, 27, 47, 17, 17, 47, 58, 43, 27, 34, 12, 33, 39, 3, 
13, 25, 24, 19, 42, 39, 36, 8, 33, 11, 22, 29, 45, 21, 23, 15
), s = c(13, 16, 9, 59, 56, 36, 52, 51, 46, 24, 32, 44, 34, 15, 
11, 44, 17, 0, 10, 16, 14, 40, 52, 44, 18, 59, 45, 6, 25, 23, 
50, 26, 35, 54, 13, 20, 40, 53, 38, 11, 32, 22, 18, 40, 52, 41, 
26, 32, 54, 39, 5, 39, 39, 34, 0, 50, 2, 31, 49, 57, 11, 56, 
34, 28, 56, 16, 53, 33, 0, 57, 4, 40, 58, 4, 29, 14, 16), h0 = c(0, 
0, 0, 3, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 5, 0, 0, 2, 0, 1, 0, 1, 
0, 0, 1, 3, 0, NA, 13, 0, 0, 0, 1, 0, 2, 18, 1, 1, 0, 3, 0, 0, 
0, 1, 0, 0, 1, 0, 0, 1, 0, 0, 1, 2, 0, 0, 2, 0, 0, 0, 1, 0, 1, 
NA, 0, 0, 1, 0, 1, 3, 1, 2, 0, 0, 0, 0, 0), m0 = c(31, 19, 23, 
5, 55, 0, 22, 36, 37, 44, 32, 29, 28, 22, 31, 27, 59, 23, 38, 
11, 27, 31, 32, 50, 59, 50, 34, NA, 32, 52, 40, 44, 27, 29, 42, 
52, 48, 26, 30, 45, 52, 41, 46, 46, 31, 56, 0, 46, 36, 1, 21, 
28, 3, 21, 56, 36, 57, 14, 43, 49, 17, 17, 43, NA, 26, 48, 57, 
47, 23, 5, 29, 47, 34, 58, 26, 31, 19), s0 = c(8, 0, 21, 36, 
9, 12, 36, 33, 33, 3, 37, 16, 40, 53, 24, 51, 50, 56, 16, 57, 
9, 35, 24, 14, 16, 22, 45, NA, 52, 27, 14, 55, 4, 5, 17, 45, 
24, 59, 28, 10, 13, 42, 25, 58, 56, 10, 54, 6, 35, 51, 38, 23, 
7, 21, 36, 6, 44, 48, 27, 4, 38, 56, 25, NA, 13, 35, 48, 9, 41, 
18, 51, 6, 52, 20, 33, 8, 0), dist = c(2, 2, 3, 21, 6, 7, 1.5, 
5, 6, 5, 4, 10.5, 4.5, 3, 30.5, 3.5, 7.5, 14, 5, 9, 4, 8, 3.5, 
7, 12, 16, 5, 5.5, 46, 6, 4.5, 6.5, 8, 2.5, 13, 95, 14, 10, 4.5, 
28, 6, 6, 6, 9, 4, 4.5, 6, 5.5, 3.5, 5, 2, 2, 6, 14, 7, 3, 15, 
2.5, 5.5, 6, 9, 2.25, 10, 4, 2, 6, 16, 5, 8, 18, 10, 16, 4.5, 
6.5, 3.6, 2.5, 2), ht = c(2000, 650, 750, 4100, 2500, 1800, 1400, 
700, 900, 1200, 1300, 3500, 800, 1000, 8000, 800, 800, 5000, 
1250, 3192, 800, 2866, 1250, 600, 4000, 7500, 800, 800, 7500, 
1400, 2200, 650, 2500, 1400, 5500, 9200, 2200, 2000, 1500, 2100, 
1500, 900, 2000, 2950, 600, 2400, 1400, 728, 1500, 1200, 900, 
900, 2500, 4900, 500, 1223, 5500, 800, 741, 1220, 2200, 500, 
4400, 2000, 1500, 1400, 2250, 1700, 2710, 4900, 2300, 6200, 1500, 
1000, 650, 2000, 650), time = c(0.403611111111111, 0.254444444444444, 
0.485833333333333, 2.39972222222222, 0.782222222222222, 0.793333333333333, 
0.314444444444444, 0.464166666666667, 0.546111111111111, 0.623333333333333, 
0.458888888888889, 1.27888888888889, 0.409444444444444, 0.3375, 
4.46972222222222, 0.395555555555556, 0.738055555555555, 1.98333333333333, 
0.552777777777778, 1.03777777777778, 0.387222222222222, 1.22777777777778, 
0.431111111111111, 0.678888888888889, 1.72166666666667, 3.11638888888889, 
0.495833333333333, 0.618333333333333, 8.30694444444445, 0.739722222222222, 
0.563888888888889, 0.623888888888889, 1.19305555555556, 0.381666666666667, 
2.22027777777778, 15.4388888888889, 1.54444444444444, 1.19805555555556, 
0.427222222222222, 3.18638888888889, 0.742222222222222, 0.572777777777778, 
0.638333333333333, 1.32777777777778, 0.447777777777778, 0.744722222222222, 
0.773888888888889, 0.508888888888889, 0.465, 0.794166666666667, 
0.284722222222222, 0.294166666666667, 0.794166666666667, 1.97611111111111, 
0.716666666666667, 0.463888888888889, 2.56722222222222, 0.208611111111111, 
0.563611111111111, 0.665833333333333, 1.05305555555556, 0.232222222222222, 
1.42611111111111, 0.407777777777778, 0.332222222222222, 0.704444444444444, 
1.66472222222222, 0.609166666666667, 1.13333333333333, 2.56583333333333, 
1.18444444444444, 2.37777777777778, 0.499444444444444, 0.751111111111111, 
0.358055555555556, 0.387222222222222, 0.254444444444444), timef = c(0.518888888888889, 
0.316666666666667, 0.389166666666667, 3.09333333333333, 0.919166666666667, 
1.00333333333333, 0.376666666666667, 0.609166666666667, 0.625833333333333, 
0.734166666666667, 0.543611111111111, 1.48777777777778, 0.477777777777778, 
0.381388888888889, 5.52333333333333, 0.464166666666667, 0.997222222222222, 
2.39888888888889, 0.637777777777778, 1.19916666666667, 0.4525, 
1.52638888888889, 0.54, 0.837222222222222, 1.98777777777778, 
3.83944444444444, 0.579166666666667, NA, 13.5477777777778, 0.874166666666667, 
0.670555555555556, 0.748611111111111, 1.45111111111111, 0.484722222222222, 
2.70472222222222, 18.8791666666667, 1.80666666666667, 1.44972222222222, 
0.507777777777778, 3.75277777777778, 0.870277777777778, 0.695, 
0.773611111111111, 1.78277777777778, 0.532222222222222, 0.936111111111111, 
1.015, 0.768333333333333, 0.609722222222222, 1.03083333333333, 
0.360555555555556, 0.473055555555556, 1.05194444444444, 2.35583333333333, 
0.943333333333333, 0.601666666666667, 2.96222222222222, 0.246666666666667, 
0.724166666666667, 0.817777777777778, 1.29388888888889, 0.298888888888889, 
1.72361111111111, NA, 0.436944444444444, 0.809722222222222, 1.96333333333333, 
0.785833333333333, 1.39472222222222, 3.08833333333333, 1.4975, 
2.785, 0.581111111111111, 0.972222222222222, 0.4425, 0.518888888888889, 
0.316666666666667), type = structure(list(type = structure(c("uphill", 
"other", "other", "relay", "hill", "hill", "hill", "hill", "hill", 
"hill", "hill", "hill", "other", "uphill", "marathon", "hill", 
"relay", "hill", "hill", "hill", "hill", "hill", "hill", "hill", 
"other", "other", "hill", "hill", "hill", "hill", "other", "hill", 
"hill", "hill", "hill", "other", "other", "hill", "other", "other", 
"hill", "hill", "hill", "hill", "hill", "hill", "hill", "hill", 
"hill", "other", "hill", "hill", "hill", "hill", "hill", "hill", 
"hill", "hill", "hill", "hill", "hill", "hill", "hill", "other", 
"hill", "hill", "hill", "hill", "hill", "hill", "hill", "hill", 
"hill", "other", "relay", "uphill", "other"), class = "AsIs")), .Names = "type", row.names = c("1", 
"2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", 
"14", "15", "16", "17", "18", "19", "20", "21", "22", "23", "24", 
"26", "27", "28", "29", "30", "31", "32", "33", "34", "35", "36", 
"37", "38", "39", "40", "41", "42", "43", "44", "45", "46", "47", 
"48", "49", "50", "51", "52", "53", "54", "55", "56", "57", "58", 
"59", "60", "61", "62", "63", "64", "65", "66", "67", "68", "69", 
"70", "71", "72", "73", "74", "75", "76", "77", "78"), class = "data.frame")), .Names = c("h", 
"m", "s", "h0", "m0", "s0", "dist", "ht", "time", "timef", "type"
), row.names = c("Aonach Mor Gondola", "Broughton Brewery", "El-Brim-Ick", 
"The Devils Burdens", "Tiso Carnethy", "Criffel", "Chapelgill", 
"Norman's Law", "Craig Dunain", "Knockfarrel", "Screel", "O.P.S. Clachnaben", 
"Hunters Bog", "Aberfoyle Dash", "Manx Mountain", "Whangie Whizz", 
"Ben Rha", "Stuc A'Chroin", "29th Dumyat", "Ben Lomond", "Kinnoull", 
"Goatfell", "Scottish Nuclear Kaim", "Ardoch Rig", "Culter Fell", 
"Isle of Jura", "Scolty", "Cornalees", "12 Trig Trog", "Kilpatricks", 
"Glas Tulaichean", "Traprain", "Yetholm", "Ben Sheann", "Glen Rosa", 
"West Highland Way", "Tiso Seven Hills", "Scottish Borders", 
"Eildon Two", "Lairig Ghru", "Cort-ma", "White Tops", "Dollar", 
"Ben Tee", "Black Hill", "Glamaig", "Urie Loch", "Whiteash", 
"Meall Ant-Suidhe", "Half Ben Nevis", "Lochaber AC", "Lochaber Highland", 
"Mash Hill", "Ben Rhinnes", "Beinn Lee", "Creag Dubh", "Glen Clova", 
"Caerketton", "Wideford", "Tap O'North", "Lomonds", "Oban", "Ben Nevis", 
"Braemar", "Moffat Beef Tub", "Cairn William", "Corrieyairick", 
"Morven", "Merrick", "Two Breweries", "Manor Water", "Pentland", 
"Tinto", "Druim Fada", "Elrick", "Gondola", "Greenmantle"), class = "data.frame")

==> DAAG_0.37.tar.gz: DAAG/data/hills2000.R <==
"hills2000" <-
structure(list(h = c(0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 
4, 0, 0, 1, 0, 1, 0, 1, 0, 0, 1, 3, 0, 0, 8, 0, 0, 0, 1, 0, 2, 
15, 1, 1, 0, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 
0, 2, 0, 0, 0, 1, 0, 1, 0, 0, 0, 1, 0, 1, 2, 1, 2, 0, 0, 0, 0, 
0), m = c(24, 15, 29, 23, 46, 47, 18, 27, 32, 37, 27, 16, 24, 
20, 28, 23, 44, 59, 33, 2, 23, 13, 25, 40, 43, 6, 29, 37, 18, 
44, 33, 37, 11, 22, 13, 26, 32, 11, 25, 11, 44, 34, 38, 19, 26, 
44, 46, 30, 27, 47, 17, 17, 47, 58, 43, 27, 34, 12, 33, 39, 3, 
13, 25, 24, 19, 42, 39, 36, 8, 33, 11, 22, 29, 45, 21, 23, 15
), s = c(13, 16, 9, 59, 56, 36, 52, 51, 46, 24, 32, 44, 34, 15, 
11, 44, 17, 0, 10, 16, 14, 40, 52, 44, 18, 59, 45, 6, 25, 23, 
50, 26, 35, 54, 13, 20, 40, 53, 38, 11, 32, 22, 18, 40, 52, 41, 
26, 32, 54, 39, 5, 39, 39, 34, 0, 50, 2, 31, 49, 57, 11, 56, 
34, 28, 56, 16, 53, 33, 0, 57, 4, 40, 58, 4, 29, 14, 16), h0 = c(0, 
0, 0, 3, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 5, 0, 0, 2, 0, 1, 0, 1, 
0, 0, 1, 3, 0, NA, 13, 0, 0, 0, 1, 0, 2, 18, 1, 1, 0, 3, 0, 0, 
0, 1, 0, 0, 1, 0, 0, 1, 0, 0, 1, 2, 0, 0, 2, 0, 0, 0, 1, 0, 1, 
NA, 0, 0, 1, 0, 1, 3, 1, 2, 0, 0, 0, 0, 0), m0 = c(31, 19, 23, 
5, 55, 0, 22, 36, 37, 44, 32, 29, 28, 22, 31, 27, 59, 23, 38, 
11, 27, 31, 32, 50, 59, 50, 34, NA, 32, 52, 40, 44, 27, 29, 42, 
52, 48, 26, 30, 45, 52, 41, 46, 46, 31, 56, 0, 46, 36, 1, 21, 
28, 3, 21, 56, 36, 57, 14, 43, 49, 17, 17, 43, NA, 26, 48, 57, 
47, 23, 5, 29, 47, 34, 58, 26, 31, 19), s0 = c(8, 0, 21, 36, 
9, 12, 36, 33, 33, 3, 37, 16, 40, 53, 24, 51, 50, 56, 16, 57, 
9, 35, 24, 14, 16, 22, 45, NA, 52, 27, 14, 55, 4, 5, 17, 45, 
24, 59, 28, 10, 13, 42, 25, 58, 56, 10, 54, 6, 35, 51, 38, 23, 
7, 21, 36, 6, 44, 48, 27, 4, 38, 56, 25, NA, 13, 35, 48, 9, 41, 
18, 51, 6, 52, 20, 33, 8, 0), dist = c(2, 2, 3, 21, 6, 7, 1.5, 
5, 6, 5, 4, 10.5, 4.5, 3, 30.5, 3.5, 7.5, 14, 5, 9, 4, 8, 3.5, 
7, 12, 16, 5, 5.5, 46, 6, 4.5, 6.5, 8, 2.5, 13, 95, 14, 10, 4.5, 
28, 6, 6, 6, 9, 4, 4.5, 6, 5.5, 3.5, 5, 2, 2, 6, 14, 7, 3, 15, 
2.5, 5.5, 6, 9, 2.25, 10, 4, 2, 6, 16, 5, 8, 18, 10, 16, 4.5, 
6.5, 3.6, 2.5, 2), climb = c(2000, 650, 750, 4100, 2500, 1800, 1400, 
700, 900, 1200, 1300, 3500, 800, 1000, 8000, 800, 800, 5000, 
1250, 3192, 800, 2866, 1250, 600, 4000, 7500, 800, 800, 7500, 
1400, 2200, 650, 2500, 1400, 5500, 9200, 2200, 2000, 1500, 2100, 
1500, 900, 2000, 2950, 600, 2400, 1400, 728, 1500, 1200, 900, 
900, 2500, 4900, 500, 1223, 5500, 800, 741, 1220, 2200, 500, 
4400, 2000, 1500, 1400, 2250, 1700, 2710, 4900, 2300, 6200, 1500, 
1000, 650, 2000, 650), time = c(0.403611111111111, 0.254444444444444, 
0.485833333333333, 2.39972222222222, 0.782222222222222, 0.793333333333333, 
0.314444444444444, 0.464166666666667, 0.546111111111111, 0.623333333333333, 
0.458888888888889, 1.27888888888889, 0.409444444444444, 0.3375, 
4.46972222222222, 0.395555555555556, 0.738055555555555, 1.98333333333333, 
0.552777777777778, 1.03777777777778, 0.387222222222222, 1.22777777777778, 
0.431111111111111, 0.678888888888889, 1.72166666666667, 3.11638888888889, 
0.495833333333333, 0.618333333333333, 8.30694444444445, 0.739722222222222, 
0.563888888888889, 0.623888888888889, 1.19305555555556, 0.381666666666667, 
2.22027777777778, 15.4388888888889, 1.54444444444444, 1.19805555555556, 
0.427222222222222, 3.18638888888889, 0.742222222222222, 0.572777777777778, 
0.638333333333333, 1.32777777777778, 0.447777777777778, 0.744722222222222, 
0.773888888888889, 0.508888888888889, 0.465, 0.794166666666667, 
0.284722222222222, 0.294166666666667, 0.794166666666667, 1.97611111111111, 
0.716666666666667, 0.463888888888889, 2.56722222222222, 0.208611111111111, 
0.563611111111111, 0.665833333333333, 1.05305555555556, 0.232222222222222, 
1.42611111111111, 0.407777777777778, 0.332222222222222, 0.704444444444444, 
1.66472222222222, 0.609166666666667, 1.13333333333333, 2.56583333333333, 
1.18444444444444, 2.37777777777778, 0.499444444444444, 0.751111111111111, 
0.358055555555556, 0.387222222222222, 0.254444444444444), timef = c(0.518888888888889, 
0.316666666666667, 0.389166666666667, 3.09333333333333, 0.919166666666667, 
1.00333333333333, 0.376666666666667, 0.609166666666667, 0.625833333333333, 
0.734166666666667, 0.543611111111111, 1.48777777777778, 0.477777777777778, 
0.381388888888889, 5.52333333333333, 0.464166666666667, 0.997222222222222, 
2.39888888888889, 0.637777777777778, 1.19916666666667, 0.4525, 
1.52638888888889, 0.54, 0.837222222222222, 1.98777777777778, 
3.83944444444444, 0.579166666666667, NA, 13.5477777777778, 0.874166666666667, 
0.670555555555556, 0.748611111111111, 1.45111111111111, 0.484722222222222, 
2.70472222222222, 18.8791666666667, 1.80666666666667, 1.44972222222222, 
0.507777777777778, 3.75277777777778, 0.870277777777778, 0.695, 
0.773611111111111, 1.78277777777778, 0.532222222222222, 0.936111111111111, 
1.015, 0.768333333333333, 0.609722222222222, 1.03083333333333, 
0.360555555555556, 0.473055555555556, 1.05194444444444, 2.35583333333333, 
0.943333333333333, 0.601666666666667, 2.96222222222222, 0.246666666666667, 
0.724166666666667, 0.817777777777778, 1.29388888888889, 0.298888888888889, 
1.72361111111111, NA, 0.436944444444444, 0.809722222222222, 1.96333333333333, 
0.785833333333333, 1.39472222222222, 3.08833333333333, 1.4975, 
2.785, 0.581111111111111, 0.972222222222222, 0.4425, 0.518888888888889, 
0.316666666666667), type = structure(list(type = structure(c("uphill", 
"other", "other", "relay", "hill", "hill", "hill", "hill", "hill", 
"hill", "hill", "hill", "other", "uphill", "marathon", "hill", 
"relay", "hill", "hill", "hill", "hill", "hill", "hill", "hill", 
"other", "other", "hill", "hill", "hill", "hill", "other", "hill", 
"hill", "hill", "hill", "other", "other", "hill", "other", "other", 
"hill", "hill", "hill", "hill", "hill", "hill", "hill", "hill", 
"hill", "other", "hill", "hill", "hill", "hill", "hill", "hill", 
"hill", "hill", "hill", "hill", "hill", "hill", "hill", "other", 
"hill", "hill", "hill", "hill", "hill", "hill", "hill", "hill", 
"hill", "other", "relay", "uphill", "other"), class = "AsIs")), .Names = "type", row.names = c("1", 
"2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", 
"14", "15", "16", "17", "18", "19", "20", "21", "22", "23", "24", 
"26", "27", "28", "29", "30", "31", "32", "33", "34", "35", "36", 
"37", "38", "39", "40", "41", "42", "43", "44", "45", "46", "47", 
"48", "49", "50", "51", "52", "53", "54", "55", "56", "57", "58", 
"59", "60", "61", "62", "63", "64", "65", "66", "67", "68", "69", 
"70", "71", "72", "73", "74", "75", "76", "77", "78"), class = "data.frame")), .Names = c("h", 
"m", "s", "h0", "m0", "s0", "dist", "climb", "time", "timef", "type"
), row.names = c("Aonach Mor Gondola", "Broughton Brewery", "El-Brim-Ick", 
"The Devils Burdens", "Tiso Carnethy", "Criffel", "Chapelgill", 
"Norman's Law", "Craig Dunain", "Knockfarrel", "Screel", "O.P.S. Clachnaben", 
"Hunters Bog", "Aberfoyle Dash", "Manx Mountain", "Whangie Whizz", 
"Ben Rha", "Stuc A'Chroin", "29th Dumyat", "Ben Lomond", "Kinnoull", 
"Goatfell", "Scottish Nuclear Kaim", "Ardoch Rig", "Culter Fell", 
"Isle of Jura", "Scolty", "Cornalees", "12 Trig Trog", "Kilpatricks", 
"Glas Tulaichean", "Traprain", "Yetholm", "Ben Sheann", "Glen Rosa", 
"West Highland Way", "Tiso Seven Hills", "Scottish Borders", 
"Eildon Two", "Lairig Ghru", "Cort-ma", "White Tops", "Dollar", 
"Ben Tee", "Black Hill", "Glamaig", "Urie Loch", "Whiteash", 
"Meall Ant-Suidhe", "Half Ben Nevis", "Lochaber AC", "Lochaber Highland", 
"Mash Hill", "Ben Rhinnes", "Beinn Lee", "Creag Dubh", "Glen Clova", 
"Caerketton", "Wideford", "Tap O'North", "Lomonds", "Oban", "Ben Nevis", 
"Braemar", "Moffat Beef Tub", "Cairn William", "Corrieyairick", 
"Morven", "Merrick", "Two Breweries", "Manor Water", "Pentland", 
"Tinto", "Druim Fada", "Elrick", "Gondola", "Greenmantle"), class = "data.frame")
